import os

PROGNAME='redhat-config-packages'
GLADEDIR='/usr/share/redhat-config-packages/glade/'
PIXMAPSDIR='/usr/share/pixmaps/'
RHCPIXMAPSDIR='/usr/share/pixmaps/redhat-config-packages/'
MAX_PACKAGE_REMOVE_WARN=200
COMPS_BLACK_LIST = ['base-x', 'gnome-desktop', 'kde-desktop', 'printing']


# takes an argument of a list of (arg, val) tuples from getopt.getopt
def get_method(args = []):
    import method

    tree = None
    isodir = None
    do_help = 0
    
    for (arg, val) in args:
        if arg in ('-t', '--tree'):
            tree = val
        elif (arg == '--isodir'):
            isodir = val

    if tree is not None:
        return method.TreeInstallMethod(tree)
    elif isodir is not None:
        return method.LoopbackIsoInstallMethod(isodir)

    # they didn't specify a method -- fall back to the default behavior

    # note: this is completely unsupported.  this file is highly likely to
    # go away in the future.  do not count on its existence.  it is mainly
    # a convenience to people who like reading source code ;-)
    try:
        if os.access("/etc/redhat-config-packages.method", os.O_RDONLY):
            f = open("/etc/redhat-config-packages.method", "r")
            lines = f.readlines()
            f.close()

            for line in lines:
                if line.startswith("TREE="):
                    tree = line[5:]
                    return method.TreeInstallMethod(tree)
                elif line.startswith("ISODIR="):
                    isodir = line[7:]
                    return method.LoopbackIsoInstallMethod(isodir)
                elif line.startswith("DEVICE="):
                    device = line[7:]
                    return method.RedHatCdromInstallMethod(device)

    except:
        pass

    return method.RedHatCdromInstallMethod()

def default_short_args():
    return "t:"

def default_long_args():
    return ["tree=", "isodir=", "help"]

def default_args_help():
    return "[--help] [-t=|--tree=PATH] [--isodir=PATH]"


def get_fallback_mountpoint():
    # note: this is completely unsupported.  this file is highly likely to
    # go away in the future.  do not count on its existence.  it is mainly
    # a convenience to people who like reading source code ;-)
    try:
        if os.access("/etc/redhat-config-packages.method", os.O_RDONLY):
            f = open("/etc/redhat-config-packages.method", "r")
            lines = f.readlines()
            f.close()

            for line in lines:
                if line.startswith("MOUNTPOINT="):
                    return line[11:]
    except:
        pass

    return "/mnt/cdrom"
    
