#
# hdrlist.py - functions for dealing with header lists
#
# Based on code originally from anaconda's comps.py
#
# Copyright 2002 Red Hat, Inc.
#

import os, sys
import rpm404 as rpm
import method
from comps import Package

if os.environ.has_key("RCPUPGRADE") and os.environ["RCPUPGRADE"] == "1":
    ALLOWUPGRADE = 1
else:
    ALLOWUPGRADE = 0

class HeaderList(dict):
    def selected(self):
        l = []
        keys = self.keys()
        keys.sort()
        for name in keys:
            if self[name].isSelected():
                l.append(self[name])
        return l

    def mergeRpmDb(self, instPath = "/"):
        installedmethod = method.InstalledPackageMethod()
        
        db = rpm.opendb(0, instPath)
        i = db.firstkey()
        while i is not None:
            h = db[i]
            name = h[rpm.RPMTAG_NAME]
            if self.has_key(name):
                val = rpm.versionCompare(h, self[name].h)
                if val < 0:
#                    print "have an older version installed of %s" %(name,)
                    if ALLOWUPGRADE == 1:
                        self[name].selectForUpgrade()
                elif val > 0:
                    self[name] = Package(h, installedmethod)
#                    print "have a newer version installed of %s" %(name,)
                else:
                    # they're the same version, don't worry about it
                    pass
            else:
                self[name] = Package(h, installedmethod)
            i = db.nextkey(i)

    def preordered(self):
        preordered = 1
	for h in self.selected():
            if h[1000003] == None:
                preordered = 0
                break
        return preordered

    def addHeaders(self, hdlist, method):
        """hdlist is a list of rpm header objects"""

        for h in hdlist:
            name = h[rpm.RPMTAG_NAME]
            score1 = rpm.archscore(h[rpm.RPMTAG_ARCH])
            if score1 == 0:
                continue
            if self.has_key(name):
                val = rpm.versionCompare(h, self[name].h)
                if val < 0:
                    continue
                elif val < 0:
                    self[name] = Package(h, method)
                elif val == 0:
                    score2 = rpm.archscore(self[name].h[rpm.RPMTAG_ARCH])
                    if (score1 < score2):
                        self[name] = Package(h, method)
            else:
                self[name] = Package(h, method)
                    

    def __init__(self, hdlist, method):
        dict.__init__(self)
        self.hdlist = hdlist

        self.addHeaders(hdlist, method)
            
        
class HeaderListFromFile(HeaderList):
    def __init__(self, path, method, update_method=None):
        hdlist = rpm.readHeaderListFromFile(path)
        if update_method: update_method(0.7)
        HeaderList.__init__(self, hdlist, method)
        if update_method: update_method(1.0)

        # FIXME: this is magic that mostly happens to work with current
        # stuff.  the whole hdlist + hdlist2 thing needs to be revisited
        # at some point
        path2 = "%s2" %(path,)
        if os.access(path2, os.O_RDONLY):
            fd = os.open(path2, os.O_RDONLY)
            rpm.mergeHeaderListFromFD(self.hdlist, fd, 1000004)
            os.close(fd)

                

if __name__ == "__main__":
    path = sys.argv[1]
    foo = method.InstalledPackageMethod
    hdlist = HeaderListFromFile(path, foo)

    for pkg in hdlist:
        print pkg
